import React, { Suspense } from 'react'
import { Box } from '@chakra-ui/core'
import { OrbitControls, Sky } from '@react-three/drei'
import { Canvas } from 'react-three-fiber'
import { PointerLockControls } from '@react-three/drei'

import Plaza from '../models/Plaza'
import PlazaCollision from '../models/Plaza_collision'
import { Physics } from '@react-three/cannon'
import Player from './Player'

const Museo: React.FC = () => {
  return (
    <Box w="100vw" h="100vh">
      <Canvas shadowMap>
        <ambientLight />
        <pointLight position={[10, 10, 10]} />
        <Suspense fallback={null}>
          <Plaza />
          <Physics
            gravity={[0, 0, 0]}
            iterations={10}
            step={1 / 60}
            size={10}
            broadphase="SAP"
            axisIndex={1}
            defaultContactMaterial={{
              friction: 0,
              restitution: 0,
            }}
          >
            <PlazaCollision />
            <Player />
          </Physics>
        </Suspense>
        <Sky
          distance={550000}
          azimuth={0.25}
          mieDirectionalG={0.83}
          mieCoefficient={0.008}
          inclination={0.5}
          turbidity={8}
          rayleigh={2.9}
        />
        <PointerLockControls />
      </Canvas>
    </Box>
  )
}

export default Museo
